export function openAndScroll({ it, scrollTarget }: { it: string, scrollTarget?: string }) {
    const gotoandopen = (_event: React.MouseEvent<HTMLElement, MouseEvent>) => {
        _event.preventDefault(); // Prevent default anchor behavior

        console.log(`openAndScroll called with it: ${it} and scrollTarget: ${scrollTarget}`);

        // Attempt to find the elements
        const subtabElement = document.getElementById(it);
        const parentElementId = "parent-" + it.replace("tab-", "");
        const parentElement = document.getElementById(parentElementId);

        console.log(`subtabElement with ID ${it}: `, subtabElement);
        console.log(`parentElement with ID ${parentElementId}: `, parentElement);

        if (subtabElement && parentElement) {
            console.log("Found subtabElement and parentElement.");
            // Show the selected tab in the sidebar and add active class
            subtabElement.style.display = "block";
            parentElement.classList.add("active-sideitem");
        } else {
            console.error(`Subtab element or parent element not found for ID: ${it}`);
        }

        // If a scroll target is provided, scroll to that element on the page
        if (scrollTarget) {
            const targetElement = document.getElementById(scrollTarget);
            if (targetElement) {
                console.log(`Scrolling to element with ID: ${scrollTarget}`);
                
                // Get the position of the element relative to the document
                const elementRect = targetElement.getBoundingClientRect();
                const elementTop = elementRect.top + window.scrollY;
                
                // Calculate the middle of the viewport
                const viewportHeight = window.innerHeight;
                const scrollOffset = elementTop - (viewportHeight / 5 - targetElement.offsetHeight / 2);
               /*  
                console.log(`Element Top: ${elementTop}`);
                console.log(`Viewport Height: ${viewportHeight}`);
                console.log(`Scroll Offset: ${scrollOffset}`); */
                
                window.scrollTo({
                    top: scrollOffset,
                    behavior: "smooth"
                });
            } else {
                console.error(`Scroll target element not found for ID: ${scrollTarget}`);
            }
        }
    }
    return gotoandopen;
}


export function openAndCloseAndScroll({ it, scrollTarget, close }: { it: string, scrollTarget?: string, close: Array<string> }) {
    const gotoandopen = (_event: React.MouseEvent<HTMLElement, MouseEvent>) => {
        _event.preventDefault(); // Prevent default anchor behavior

        console.log(`openAndScroll called with it: ${it} and scrollTarget: ${scrollTarget}`);

        // Attempt to find the elements
        const subtabElement = document.getElementById(it);
        const parentElementId = "parent-" + it.replace("tab-", "");
        const parentElement = document.getElementById(parentElementId);

        
        if (close) {
            for (let idx in close){
                let tab = "tab-" + close[idx]; 
                let parent = "parent-" + close[idx]; 
                document.getElementById(tab)!.style.display = "none"; 
                document.getElementById(parent)!.classList.remove("active-sideitem");
            }
        }
        
        console.log(`subtabElement with ID ${it}: `, subtabElement);
        console.log(`parentElement with ID ${parentElementId}: `, parentElement);

        if (subtabElement && parentElement) {
            console.log("Found subtabElement and parentElement.");
            // Show the selected tab in the sidebar and add active class
            subtabElement.style.display = "block";
            parentElement.classList.add("active-sideitem");
        } else {
            console.error(`Subtab element or parent element not found for ID: ${it}`);
        }

        // If a scroll target is provided, scroll to that element on the page
        if (scrollTarget) {
            const targetElement = document.getElementById(scrollTarget);
            if (targetElement) {
                console.log(`Scrolling to element with ID: ${scrollTarget}`);
                
                // Get the position of the element relative to the document
                const elementRect = targetElement.getBoundingClientRect();
                const elementTop = elementRect.top + window.scrollY;
                
                // Calculate the middle of the viewport
                const viewportHeight = window.innerHeight;
                const scrollOffset = elementTop - (viewportHeight / 5 - targetElement.offsetHeight / 2);
               /*  
                console.log(`Element Top: ${elementTop}`);
                console.log(`Viewport Height: ${viewportHeight}`);
                console.log(`Scroll Offset: ${scrollOffset}`); */
                
                window.scrollTo({
                    top: scrollOffset,
                    behavior: "smooth"
                });
            } else {
                console.error(`Scroll target element not found for ID: ${scrollTarget}`);
            }
        }
    }
    return gotoandopen;
}
